/*
 * File: OlympicRingsWide.java
 * ---------------------------
 * This program draws the symbol for the Olympic games, which
 * consists of five overlapping rings in different colors.  This
 * version of the program draws several circles to make the rings
 * wider.  The number of rings is given by the constant THICKNESS.
 *
 * As of Chapter 2, students don't yet have methods or the for
 * statement and would therefore have to write this program
 * using a single unsubdivided run method, as in the original
 * version of OlympicRings.java; this code shows the program
 * as students will eventually write it.
 */

import acm.graphics.*;
import acm.program.*;
import java.awt.*;

public class OlympicRingsWide extends GraphicsProgram {

	public void run() {
		addRing(-2, -0.5, Color.BLUE);
		addRing(-1, +0.5, Color.YELLOW);
		addRing(0,  -0.5, Color.BLACK);
		addRing(+1, +0.5, Color.GREEN);
		addRing(+2, -0.5, Color.RED);
	}

/*
 * Adds a ring to the canvas which is offset by dx times the
 * ring size in the horizontal dimension and dy times the
 * ring size in the vertical dimension.  The ring is displayed
 * in the specified color.
 */
	private void addRing(double dx, double dy, Color color) {
		double r = RING_RADIUS;
		double delta = r * (1 - RING_OVERLAP) * Math.sqrt(2);
		double cx = getWidth() / 2;
		double cy = getHeight() / 2;
		double xRing = cx + dx * delta;
		double yRing = cy + dy * delta;
		for (int i = 0; i < THICKNESS; i++) {
			GOval ring = new GOval(xRing - r, yRing - r, 2 * r, 2 * r);
			ring.setColor(color);
			add(ring);
			r -= 1;
		}
	}

/* Private constants */
	private static final double RING_RADIUS = 50;
	private static final double RING_OVERLAP = 0.15;
	private static final int THICKNESS = 3;

}
